============================================================
``psyclone.tests.psyir.frontend.fparser2_derived_type_test``
============================================================

.. automodule:: psyclone.tests.psyir.frontend.fparser2_derived_type_test

   .. contents::
      :local:

.. currentmodule:: psyclone.tests.psyir.frontend.fparser2_derived_type_test
